==> Paws-0.35.tar.gz: Paws-0.35/lib/Paws/OpsWorks/AssociateElasticIp.pm <==

package Paws::OpsWorks::AssociateElasticIp;
  use Moose;
  has ElasticIp => (is => 'ro', isa => 'Str', required => 1);
  has InstanceId => (is => 'ro', isa => 'Str');

  use MooseX::ClassAttribute;

  class_has _api_call => (isa => 'Str', is => 'ro', default => 'AssociateElasticIp');
  class_has _returns => (isa => 'Str', is => 'ro', default => 'Paws::API::Response');
  class_has _result_key => (isa => 'Str', is => 'ro');
1;

### main pod documentation begin ###

=head1 NAME

Paws::OpsWorks::AssociateElasticIp - Arguments for method AssociateElasticIp on Paws::OpsWorks

=head1 DESCRIPTION

This class represents the parameters used for calling the method AssociateElasticIp on the 
AWS OpsWorks service. Use the attributes of this class
as arguments to method AssociateElasticIp.

You shouldn't make instances of this class. Each attribute should be used as a named argument in the call to AssociateElasticIp.

As an example:

  $service_obj->AssociateElasticIp(Att1 => $value1, Att2 => $value2, ...);

Values for attributes that are native types (Int, String, Float, etc) can passed as-is (scalar values). Values for complex Types (objects) can be passed as a HashRef. The keys and values of the hashref will be used to instance the underlying object.

=head1 ATTRIBUTES


=head2 B<REQUIRED> ElasticIp => Str

The Elastic IP address.



=head2 InstanceId => Str

The instance ID.




=head1 SEE ALSO

This class forms part of L<Paws>, documenting arguments for method AssociateElasticIp in L<Paws::OpsWorks>

=head1 BUGS and CONTRIBUTIONS

The source code is located here: https://github.com/pplu/aws-sdk-perl

Please report bugs to: https://github.com/pplu/aws-sdk-perl/issues

=cut

==> Paws-0.44.tar.gz: Paws-0.44/lib/Paws/OpsWorks/AssociateElasticIp.pm <==

package Paws::OpsWorks::AssociateElasticIp;
  use Moose;
  has ElasticIp => (is => 'ro', isa => 'Str', required => 1);
  has InstanceId => (is => 'ro', isa => 'Str');

  use MooseX::ClassAttribute;

  class_has _api_call => (isa => 'Str', is => 'ro', default => 'AssociateElasticIp');
  class_has _returns => (isa => 'Str', is => 'ro', default => 'Paws::API::Response');
  class_has _result_key => (isa => 'Str', is => 'ro');
1;

### main pod documentation begin ###

=head1 NAME

Paws::OpsWorks::AssociateElasticIp - Arguments for method AssociateElasticIp on L<Paws::OpsWorks>

=head1 DESCRIPTION

This class represents the parameters used for calling the method AssociateElasticIp on the
L<AWS OpsWorks|Paws::OpsWorks> service. Use the attributes of this class
as arguments to method AssociateElasticIp.

You shouldn't make instances of this class. Each attribute should be used as a named argument in the call to AssociateElasticIp.

=head1 SYNOPSIS

    my $opsworks = Paws->service('OpsWorks');
    $opsworks->AssociateElasticIp(
      ElasticIp  => 'MyString',
      InstanceId => 'MyString',    # OPTIONAL
    );

Values for attributes that are native types (Int, String, Float, etc) can passed as-is (scalar values). Values for complex Types (objects) can be passed as a HashRef. The keys and values of the hashref will be used to instance the underlying object.
For the AWS API documentation, see L<https://docs.aws.amazon.com/goto/WebAPI/opsworks/AssociateElasticIp>

=head1 ATTRIBUTES


=head2 B<REQUIRED> ElasticIp => Str

The Elastic IP address.



=head2 InstanceId => Str

The instance ID.




=head1 SEE ALSO

This class forms part of L<Paws>, documenting arguments for method AssociateElasticIp in L<Paws::OpsWorks>

=head1 BUGS and CONTRIBUTIONS

The source code is located here: L<https://github.com/pplu/aws-sdk-perl>

Please report bugs to: L<https://github.com/pplu/aws-sdk-perl/issues>

=cut
